<?php

namespace Larajobs\Company\Policies;

use Litepie\User\Contracts\UserPolicy;
use Larajobs\Company\Models\Application;

class ApplicationPolicy
{

    /**
     * Determine if the given user can view the application.
     *
     * @param UserPolicy $user
     * @param Application $application
     *
     * @return bool
     */
    public function view(UserPolicy $user, Application $application)
    {
        if ($user->canDo('company.application.view') && $user->isAdmin()) {
            return true;
        }

        return $application->user_id == user_id() && $application->user_type == user_type();
    }

    /**
     * Determine if the given user can create a application.
     *
     * @param UserPolicy $user
     * @param Application $application
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company.application.create');
    }

    /**
     * Determine if the given user can update the given application.
     *
     * @param UserPolicy $user
     * @param Application $application
     *
     * @return bool
     */
    public function update(UserPolicy $user, Application $application)
    {
        if ($user->canDo('company.application.edit') && $user->isAdmin()) {
            return true;
        }

        return $application->user_id == user_id() && $application->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given application.
     *
     * @param UserPolicy $user
     * @param Application $application
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Application $application)
    {
        return $application->user_id == user_id() && $application->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given application.
     *
     * @param UserPolicy $user
     * @param Application $application
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Application $application)
    {
        if ($user->canDo('company.application.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given application.
     *
     * @param UserPolicy $user
     * @param Application $application
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Application $application)
    {
        if ($user->canDo('company.application.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
